# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowRunEventNames = typing.Union[
    typing.Literal[
        "workflow_run_started",
        "workflow_run_completed",
        "workflow_run_failed",
        "block_run_started",
        "block_run_completed",
        "block_run_failed",
        "block_state_updated",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .copilot_config import CopilotConfig
import datetime as dt
from .identity import Identity
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Copilot(UncheckedBaseModel):
    copilot_config: CopilotConfig
    last_updated_at: dt.datetime
    created_at: dt.datetime
    created_by: Identity
    last_updated_by: Identity
    revision_id: str
    copilot_id: str
    is_draft: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .number_config_default_value import NumberConfigDefaultValue
from .number_config_min_value import NumberConfigMinValue
from .number_config_max_value import NumberConfigMaxValue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class NumberConfig(UncheckedBaseModel):
    default_value: typing.Optional[NumberConfigDefaultValue] = None
    min_value: typing.Optional[NumberConfigMinValue] = None
    max_value: typing.Optional[NumberConfigMaxValue] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
